@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "kirigami" "1.0.4"
+(define-package "kirigami" "20251202.1126"
   "A unified method to fold and unfold text."
   '((emacs "26.3"))
   :url "https://github.com/jamescherti/kirigami.el"
-  :commit "b2abb0c61a08bf7ecdc194daa3e1efc53947f344"
-  :revdesc "1.0.4-0-gb2abb0c61a08"
+  :commit "b23cae12111dd193b968d6e319dff8131e7796b0"
+  :revdesc "b23cae12111d"
   :keywords '("convenience"))
